@@ -20,18 +20,19 @@ import re
 import time
 import os
 from os import path
-from calculate.lib.configparser import ConfigParserCaseSens, Error as CPError
-from calculate.lib.utils.tools import SingletonParam, Cachable
-from calculate.lib.utils.gpg import GPGError
+from ..configparser import ConfigParserCaseSens, Error as CPError
+from .tools import SingletonParam, Cachable
+from .gpg import GPGError
 from .files import writeFile, xz
-from collections import MutableMapping, OrderedDict
+from collections import OrderedDict
+from collections.abc import MutableMapping
 from functools import total_ordering
 from contextlib import contextmanager
 import io
 import threading
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -67,7 +68,7 @@ class BinhostsBase(Cachable):
 
     def __init__(self, timeout, revision_path, ts_path, last_ts, binhost_list,
                  arch, gpg=None, base=False):
-        super(BinhostsBase,self).__init__()
+        super().__init__()
         self.timeout = int(timeout)
         self.revision_path = revision_path
         self.ts_path = ts_path
@@ -88,16 +89,16 @@ class BinhostsBase(Cachable):
         try:
             with _urlopen(fn, timeout=self.timeout) as f:
                 for i, line in enumerate(f):
-                    if line.startswith("TIMESTAMP"):
-                        return line.rpartition(":")[2].strip()
+                    if line.startswith(b"TIMESTAMP"):
+                        return line.rpartition(b":")[2].strip()
                     if i > 50:
                         break
         except urllib2.URLError as e:
-            return ""
-        return ""
+            return b""
+        return b""
 
     def check_package_timestamp(self, fn, timestamp):
-        return str(timestamp) == self.fetch_package_timestamp(fn)
+        return timestamp.encode("UTF-8") == self.fetch_package_timestamp(fn)
 
     @Cachable.methodcached()
     def fetch_envdata(self, binhost):
@@ -106,7 +107,7 @@ class BinhostsBase(Cachable):
         for fn in revision_files:
             try:
                 with _urlopen(fn, timeout=self.timeout) as f:
-                    return fn, f.read()
+                    return fn, f.read().decode("UTF-8")
             except urllib2.URLError as e:
                 return None, ""
         return None, ""
@@ -116,14 +117,14 @@ class BinhostsBase(Cachable):
         if fn:
             cp = ConfigParserCaseSens()
             try:
-                cp.read_string(unicode(data))
+                cp.read_string(data)
                 base_dn = path.dirname(fn)
                 for pkg_file in cp['timestamp']:
                     if not self.check_package_timestamp(
                             path.join(base_dn, pkg_file),
                             cp['timestamp'][pkg_file]):
                         return self.BinhostStatus.Updating
-            except (CPError, KeyError):
+            except (CPError, KeyError) as e:
                 return self.BinhostStatus.BadEnv
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
@@ -160,7 +161,7 @@ class BinhostsBase(Cachable):
         return int(data)
 
     @total_ordering
-    class Binhost(object):
+    class Binhost():
         def __init__(self, parent, host):
             start_ts = time.time()
             self.host = host
@@ -222,7 +223,7 @@ class BinhostsBase(Cachable):
         Не проводить проверку базового бинхоста
         """
         def __init__(self, parent, host):
-            super(BinhostsBase.BaseBinhost, self).__init__(parent, host)
+            super().__init__(parent, host)
             self.outdated = False
             self.downgraded = False
 
@@ -280,7 +281,6 @@ class BinhostsBase(Cachable):
         :return:
         """
         data = None
-        data_asc = None
         for uri in ("Packages.xz", "Packages"):
             fn = path.join(url_binhost, uri)
             try:
@@ -294,11 +294,11 @@ class BinhostsBase(Cachable):
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
                     raise
-                data = ""
+                data = b""
         if not data:
             raise BinhostError(_("Failed to fetch Packages from binary host %s")
                                % url_binhost)
-        return data
+        return data.decode("UTF-8")
 
     @staticmethod
     def check_packages_signature(url_binhost, packages, gpg, timeout=300, sign=None):
@@ -329,8 +329,8 @@ class BinhostError(Exception):
 class BinhostSignError(BinhostError):
     pass
 
-class Binhosts(BinhostsBase):
-    __metaclass__ = SingletonParam
+class Binhosts(BinhostsBase, metaclass=SingletonParam):
+    pass
 
 class PackagesIndex(MutableMapping):
     def __init__(self, data):
