@@ -14,23 +14,22 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+
 from random import choice
 import os
 import re
 import math
 from os import path
-from calculate.lib.utils.dracut import Dracut
-from calculate.lib.utils.system import SystemPath
+from .dracut import Dracut
+from .system import SystemPath
 import sys
 import getpass
-# from types import StringType
 import string
 import glob
 import pwd
 import itertools
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
@@ -40,7 +39,7 @@ class CommonError(Exception):
     pass
 
 
-class _error(object):
+class _error():
     # Здесь ошибки, если они есть
     error = []
 
@@ -63,7 +62,7 @@ class _error(object):
             self.error.pop()
 
 
-class _warning(object):
+class _warning():
     # Здесь предупреждения
     warning = []
 
@@ -88,8 +87,7 @@ class _warning(object):
 
 def genpassword(passlen=9, chars=string.ascii_letters + string.digits):
     """Return random charset specified lenght (passlen)"""
-    return ''.join(map(lambda x: choice(chars),
-                       xrange(0, passlen)))
+    return ''.join((choice(chars) for i in range(0, passlen)))
 
 
 def getpathenv():
@@ -103,6 +101,9 @@ def getpathenv():
 
 from .files import process, listDirectory
 
+def cmp(a, b):
+    return (a > b) - (a < b)
+
 def cmpVersion(v1, v2):
     """Compare versions specified by tuple or string"""
     if isinstance(v1, str):
@@ -123,10 +124,9 @@ def getTupleVersion(ver):
                     "rc": -1}
 
     def toTuple(v):
-        return map(lambda x: suffix_value[x] if x in suffix_value else x,
-                   map(lambda x: int(x) if x.isdigit() else x,
-                       re.findall("r\d+$|\d+|[a-zA-Z+]+",
-                                  v.replace('-SNAPSHOT', ''))))
+        return [suffix_value[x] if x in suffix_value else x for x 
+            in [int(z) if z.isdigit() else z for z 
+                in re.findall("r\d+$|\d+|[a-zA-Z+]+",v.replace('-SNAPSHOT', ''))]]
 
     vers, revision = re.search("(^.*?)(-r\d+)?$", ver, re.S).groups()
     vers = toTuple(vers)
@@ -139,9 +139,7 @@ def getInstalledVideo(prefix="/"):
     """Get installed video drivers"""
     usrlib = SystemPath(prefix).usrlib
     x11Drivers = "%s/xorg/modules/drivers" % usrlib
-    return map(lambda x: x[:-7],
-               filter(lambda x: x.endswith('_drv.so'),
-                      listDirectory(x11Drivers)))
+    return [x[:-7] for x in listDirectory(x11Drivers) if x.endswith('_drv.so')]
 
 
 def getDistfilesVideo(prefix="/"):
@@ -161,10 +159,7 @@ def getDistfilesVideo(prefix="/"):
         else:
             return None
 
-    return list(set(
-        filter(None,
-               map(driver_by_fn,
-                   listDirectory(distFiles)))))
+    return list(set([x for x in map(driver_by_fn, listDirectory(distFiles)) if x]))
 
 
 def getAvailableVideo(prefix="/"):
@@ -184,12 +179,9 @@ def getPasswdUsers(minId=1000, maxId=65000, prefix="/",
         reNumb = re.compile("^\d+$")
         lenData = 7
         with open(fileName) as f:
-            userData = filter(lambda x: len(x) == lenData,
-                              map(lambda x: x.rstrip().split(":"), f))
-        userData = filter(
-            lambda x: reNumb.match(x[2]) and minId <= int(x[2]) <= maxId,
-            userData)
-        sortUsers = map(lambda x: x[0], userData)
+            userData = [x for x in (y.rstrip().split(":") for y in f) if len(x) == lenData]
+        userData = [x for x in userData if reNumb.match(x[2]) and minId <= int(x[2]) <= maxId]
+        sortUsers = [x[0] for x in userData]
         sortUsers.sort()
         retList = ["root"] + sortUsers
     return retList
@@ -200,14 +192,15 @@ def getSupportArch():
 
     Is support processor x86_64 else only i686.
     """
-    if filter(lambda x: x.startswith('flags') and " lm " in x,
-              readLinesFile('/proc/cpuinfo')):
+    # if list(filter(lambda x: x.startswith('flags') and " lm " in x,
+    #           readLinesFile('/proc/cpuinfo'))):
+    if any([x for x in readLinesFile('/proc/cpuinfo') if x.startswith('flags') and " lm " in x]):
         return ['i686', 'x86_64']
     else:
         return ['i686']
 
 
-class CmdlineParams(object):
+class CmdlineParams():
     """
     Параметры опции загрузки ядра calculate=
     """
@@ -266,10 +259,7 @@ def getValueFromCmdLine(option, num=None):
                     if name is None:
                         return value.strip()
                     if ":" in value:
-                        params = dict(
-                            map(lambda x: x.partition(':')[0::2],
-                                filter(lambda x: x,
-                                       value.split(','))))
+                        params = dict((x.partition(':')[0::2] for x in value.split(',') if x))            
                         return params.get(name, "").strip()
                     # old format
                     else:
@@ -309,20 +299,16 @@ def getVideoFromXorgLog(prefix="/", available_drivers=()):
     # Try analize Xorg.{DISPLAY}.log
     display = os.environ.get('DISPLAY', ':0')
     if display and available_drivers:
-        reDriver = re.compile('|'.join(map(lambda x: "%s_drv.so" % x,
-                                           available_drivers)))
+        reDriver = re.compile('|'.join(("%s_drv.so" % x for x in available_drivers)))
         display_number = re.search(r':(\d+)(\..*)?', display)
         reDriverName = re.compile(r'([^/]+)_drv.so')
         if display_number:
             xorg_log_file = path.join(prefix, 'var/log/Xorg.%s.log' %
                                       display_number.group(1))
             if path.exists(xorg_log_file):
-                matchStrs = map(
-                    lambda x: x.group(1),
-                    filter(lambda x: x, map(
-                        reDriverName.search,
-                        filter(lambda x: "drv" in x and reDriver.search(x),
-                               readLinesFile(xorg_log_file)))))
+                matchStrs = [x.group(1) for x in [reDriverName.search(y) 
+                    for y in readLinesFile(xorg_log_file) 
+                        if "drv" in y and reDriver.search(y)] if x]
                 if matchStrs:
                     reUnload = re.compile('UnloadModule: "(%s)"' %'|'.join(x
                         for x in matchStrs))
@@ -362,10 +348,9 @@ def getVideoFromCmdLine():
 
 
 def getVideoFromModules():
-    workedModules = map(lambda x: x[0],
-                        filter(lambda x: x[1].isdigit() and int(x[1]) > 0,
-                               map(lambda x: x.split()[:3:2],
-                                   readLinesFile('/proc/modules'))))
+    workedModules = [x[0] for x in [z.split()[:3:2] for z 
+        in readLinesFile('/proc/modules')] 
+        if x[1].isdigit() and int(x[1]) > 0]
     mapModules = {'nouveau': 'nouveau',
                   'radeon': 'radeon',
                   'i915': 'intel',
@@ -426,7 +411,7 @@ def getCompositeFromXorgconf(prefix="/"):
             if line.startswith('Section') and '"Extensions"' in line:
                 flagStartExtensions = True
     if lineComposite:
-        listOpt = filter(lambda x: x.strip(), lineComposite.split('"'))
+        listOpt = [x for x in lineComposite.split('"') if x.strip()]
         if len(listOpt) == 3:
             ret = listOpt[2].lower()
             if ret in ("on", "true", "yes", "1"):
@@ -453,23 +438,23 @@ def dict_by_columns(i, sep, key, value):
     на колонки, key - номер колонки ключей, value номер колонки значений
     """
     max_val = max(key, value)
-    return dict(
-        map(lambda x: (x[key], x[value]),
-            filter(lambda x: len(x) >= max_val,
-                   map(lambda x: x.split(sep), i))))
+    return dict(((x[key], x[value]) for x in (y.split(sep) for y in i) if len(x) >= max_val))
 
 
-from calculate.lib.utils.files import readLinesFile
+from ..utils.files import readLinesFile
 
 
 def getUserGroups(userName, prefix="/"):
     """
     Get user groups from /etc/groups
     """
-    return map(lambda x: x[0],
-               filter(lambda x: len(x) > 1 and userName in x[1].split(','),
-                      map(lambda x: x.split(':')[0::3],
-                          readLinesFile(path.join(prefix, 'etc/group')))))
+    # return list(map(lambda x: x[0],
+    #            filter(lambda x: len(x) > 1 and userName in x[1].split(','),
+    #                   map(lambda x: x.split(':')[0::3],
+    #                       readLinesFile(path.join(prefix, 'etc/group'))))))
+    return [x[0] for x in [z.split(':')[0::3] for z 
+        in readLinesFile(path.join(prefix, 'etc/group'))] 
+        if len(x) > 1 and userName in x[1].split(',')]
 
 
 def getUserPrimaryGroup(userName, prefix="/"):
@@ -491,9 +476,7 @@ def getGroups(prefix="/"):
     """
     Get groups from etc/group
     """
-    return filter(None,
-                  map(lambda x: x.split(':')[0],
-                      readLinesFile(path.join(prefix, 'etc/group'))))
+    return [x for x in [z.split(':')[0] for z in readLinesFile(path.join(prefix, 'etc/group'))] if x]
 
 
 def getPagesInterval(count, offset, length):
@@ -516,8 +499,8 @@ def mountEcryptfs(userName, userPwd, userDir):
     userPwd: пароль пользователя
     userDir: домашний каталог пользователя
     """
-    from calculate.lib.utils.files import (process, readLinesFile, STDOUT)
-    from calculate.lib.utils.mount import isMount
+    from ..utils.files import (process, readLinesFile, STDOUT)
+    from ..utils.mount import isMount
 
     if ".Private" in isMount(userDir):
         return True
@@ -575,7 +558,7 @@ def isBootstrapDataOnly(user_dir):
     Каталог содержит только сертификат, созданный командой cl-core
     а так же настроенные симлинки на .face, skel
     """
-    from calculate.lib.utils.files import find
+    from ..utils.files import find
     max_diff = 10
     skel_files = set([x for x in find('/etc/skel', onefilesystem=True,
                                       fullpath=False)
@@ -612,7 +595,7 @@ def get_fastlogin_domain_path(dv):
     Получить пути до ресурсов для определения нужно ли выполнять
     шаблоны для доменного профиля пользователя
     """
-    from calculate.lib.cl_template import LayeredIni
+    from ..cl_template import LayeredIni
     overlay_suffix_path = 'profiles/templates'
     template_paths = dv.Get('main.cl_template_path')
     for template_path in template_paths:
